==> testdisk-6.9.tar.bz2: testdisk-6.9/src/file_mid.c <==
/*

    File: file_mid.c

    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 51
    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#include <stdio.h>
#include "types.h"
#include "filegen.h"


static void register_header_check_mid(file_stat_t *file_stat);
static int header_check_mid(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
static void file_check_mid(file_recovery_t *file_recovery);

const file_hint_t file_hint_mid= {
  .extension="mid",
  .description="MIDI Musical Instrument Digital Interface",
  .min_header_distance=0,
  .max_filesize=50*1024*1024,
  .recover=1,
  .register_header_check=&register_header_check_mid
};

static const unsigned char mid_header[4]  = { 'M','T','h','d'};

static void register_header_check_mid(file_stat_t *file_stat)
{
  register_header_check(0, mid_header,sizeof(mid_header), &header_check_mid, file_stat);
}

static int header_check_mid(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
{
  if(memcmp(buffer,mid_header,sizeof(mid_header))==0)
  {
    reset_file_recovery(file_recovery_new);
    file_recovery_new->extension=file_hint_mid.extension;
    file_recovery_new->min_filesize=21;
    file_recovery_new->file_check=&file_check_mid;
    return 1;
  }
  return 0;
}

static void file_check_mid(file_recovery_t *file_recovery)
{
  const unsigned char mid_footer[3]= {0xff, 0x2f, 0x00};
  file_search_footer(file_recovery, mid_footer,sizeof(mid_footer));
}

==> testdisk_6.13.orig.tar.bz2: testdisk-6.13/src/file_mid.c <==
/*

    File: file_mid.c

    Copyright (C) 1998-2007 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 51
    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#include <stdio.h>
#include "types.h"
#include "filegen.h"


static void register_header_check_mid(file_stat_t *file_stat);
static int header_check_mid(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new);
static void file_check_mid(file_recovery_t *file_recovery);

const file_hint_t file_hint_mid= {
  .extension="mid",
  .description="MIDI Musical Instrument Digital Interface",
  .min_header_distance=0,
  .max_filesize=50*1024*1024,
  .recover=1,
  .enable_by_default=1,
  .register_header_check=&register_header_check_mid
};

static const unsigned char mid_header[4]  = { 'M','T','h','d'};

static void register_header_check_mid(file_stat_t *file_stat)
{
  register_header_check(0, mid_header,sizeof(mid_header), &header_check_mid, file_stat);
}

static int header_check_mid(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
{
  if(memcmp(buffer,mid_header,sizeof(mid_header))==0)
  {
    reset_file_recovery(file_recovery_new);
    file_recovery_new->extension=file_hint_mid.extension;
    file_recovery_new->min_filesize=21;
    file_recovery_new->file_check=&file_check_mid;
    return 1;
  }
  return 0;
}

static void file_check_mid(file_recovery_t *file_recovery)
{
  const unsigned char mid_footer[3]= {0xff, 0x2f, 0x00};
  file_search_footer(file_recovery, mid_footer, sizeof(mid_footer), 0);
}
